/************************************************************************
	buttons.c

    MicroSimon (MB Electronics Simon Clone)
    Copyright (C) 2011 Simon Inns

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

	Email: simon.inns@gmail.com

************************************************************************/

#ifndef BUTTONS_C
#define BUTTONS_C

// Global includes
#include <htc.h>

// Local includes
#include "hardware.h"
#include "buttons.h"

// Read push button states
void readButtonState(void)
{
	// Perform an ADC conversion on AN0/GPIO0
	unsigned int adcValue = 0;
	
	// Start the conversion
	GODONE = 1;
	
	// Wait for the conversion to complete
	while(GODONE);
	
	// Get the result
	adcValue = ADRESL;
	adcValue += ADRESH << 8;
	
	// Convert the ADC result into the button states
	unsigned char readState[5];
	
	if (adcValue >= 196 && adcValue < 300) readState[WHITE] = ON; 
	else readState[WHITE] = OFF; 
	
	if (adcValue >= 301 && adcValue < 402) readState[GREEN] = ON; 
	else readState[GREEN] = OFF; 
	
	if (adcValue >= 452 && adcValue < 572) readState[RED] = ON; 
	else readState[RED] = OFF; 
	
	if (adcValue >= 964 && adcValue < 1024) readState[BLUE] = ON; 
	else readState[BLUE] = OFF;
	
	// Perform switch debounce to and from ON state
	for (unsigned char button = 1; button < 5; button++)
	{
		if (currentButtonState[button] == OFF && readState[button] == ON)
		{
			if (buttonDebounceCounter[button] > DEBOUNCE_AMOUNT)
			{
				currentButtonState[button] = ON;
				buttonDebounceCounter[button] = 0;
			}
			else buttonDebounceCounter[button]++;
		}
		else if	(currentButtonState[button] == ON && readState[button] == OFF)
		{
			if (buttonDebounceCounter[button] > DEBOUNCE_AMOUNT)
			{
				currentButtonState[button] = OFF;
				buttonDebounceCounter[button] = 0;
			}
			else buttonDebounceCounter[button]++;
		}
		else buttonDebounceCounter[button] = 0;	
	}
}

#endif